## Introduction

Python wrapper for [OpenFst][openfst] and its extensions from  [Kaldi][kaldi], e.g.,
`fstdeterminizestar`.

**Note**: It does not depend on Kaldi. You don't need to install
Kaldi to use this repo.

## Documentation

Please refer to <https://k2-fsa.github.io/kaldifst>
for installation and usage.

[openfst]: https://www.openfst.org/
[kaldi]: https://github.com/kaldi-asr/kaldi
